@@ -1,3 +1,6 @@
+# SPDX-FileCopyrightText: 2021 ladyada for Adafruit Industries
+# SPDX-License-Identifier: MIT
+
 """
 This example solicits that apple devices that provide notifications connect to it, initiates
 pairing, prints existing notifications and then prints any new ones as they arrive.
@@ -8,7 +11,8 @@ import adafruit_ble
 from adafruit_ble.advertising.standard import SolicitServicesAdvertisement
 import adafruit_ble_apple_notification_center as ancs
 
-radio = adafruit_ble.BLERadio()
+# PyLint can't find BLERadio for some reason so special case it here.
+radio = adafruit_ble.BLERadio()  # pylint: disable=no-member
 a = SolicitServicesAdvertisement()
 a.solicited_services.append(ancs.AppleNotificationCenterService)
 radio.start_advertising(a)
